@@ -27,7 +27,6 @@
 #include <entitytreemodel.h>
 #include <KComboBox>
 
-
 #include <QtCore/QTimer>
 #include <QIcon>
 #include <QAbstractItemView>
@@ -116,7 +115,7 @@ public:
     Private()
         : mButtonSize(16, 16)
         , mIcon(QIcon::fromTheme(QStringLiteral("list-remove")))
-        , mItemView(0)
+        , mItemView(nullptr)
     {
     }
 
@@ -155,7 +154,7 @@ QWidget *ContactGroupEditorDelegate::createEditor(QWidget *parent, const QStyleO
             return comboBox;
         } else {
             auto edit = new ContactLineEdit(isReference, ContactCompletionModel::EmailColumn, parent);
-            connect(edit, static_cast<void(ContactLineEdit::*)(QWidget*)>(&ContactLineEdit::completed),
+            connect(edit, static_cast<void(ContactLineEdit::*)(QWidget *)>(&ContactLineEdit::completed),
                     this, &ContactGroupEditorDelegate::completed);
             return edit;
         }
