@@ -24,6 +24,7 @@
 #include "job/contactgroupexpandjob.h"
 #include "standardcontactgroupformatter.h"
 #include "textbrowser_p.h"
+#include "helper_p.h"
 
 #include <collectionfetchjob.h>
 #include <entitydisplayattribute.h>
@@ -47,8 +48,8 @@ class Q_DECL_HIDDEN ContactGroupViewer::Private
 public:
     Private(ContactGroupViewer *parent)
         : mParent(parent)
-        , mExpandJob(0)
-        , mParentCollectionFetchJob(0)
+        , mExpandJob(nullptr)
+        , mParentCollectionFetchJob(nullptr)
     {
         mBrowser = new TextBrowser;
 
@@ -72,7 +73,7 @@ public:
 
         KContacts::ContactGroup group;
         group.setName(mCurrentGroupName);
-        foreach (const KContacts::Addressee &contact, mCurrentContacts) {
+        for (const KContacts::Addressee &contact : qAsConst(mCurrentContacts)) {
             group.append(KContacts::ContactGroup::Data(contact.realName(), contact.preferredEmail()));
         }
 
@@ -105,7 +106,7 @@ public:
 
     void _k_expandResult(KJob *job)
     {
-        mExpandJob = 0;
+        mExpandJob = nullptr;
 
         if (!job->error()) {
             ContactGroupExpandJob *expandJob = qobject_cast<ContactGroupExpandJob *>(job);
@@ -116,7 +117,7 @@ public:
         if (mParentCollectionFetchJob) {
             mParent->disconnect(mParentCollectionFetchJob, SIGNAL(result(KJob*)), mParent, SLOT(slotParentCollectionFetched(KJob*)));
             delete mParentCollectionFetchJob;
-            mParentCollectionFetchJob = 0;
+            mParentCollectionFetchJob = nullptr;
         }
 
         mParentCollectionFetchJob = new CollectionFetchJob(mCurrentItem.parentCollection(), CollectionFetchJob::Base, mParent);
@@ -125,7 +126,7 @@ public:
 
     void slotParentCollectionFetched(KJob *job)
     {
-        mParentCollectionFetchJob = 0;
+        mParentCollectionFetchJob = nullptr;
         mCurrentAddressBookName.clear();
 
         if (!job->error()) {
@@ -185,7 +186,7 @@ void ContactGroupViewer::setContactGroup(const Akonadi::Item &group)
 
 void ContactGroupViewer::setContactGroupFormatter(AbstractContactGroupFormatter *formatter)
 {
-    if (formatter == 0) {
+    if (formatter == nullptr) {
         d->mContactGroupFormatter = d->mStandardContactGroupFormatter;
     } else {
         d->mContactGroupFormatter = formatter;
