@@ -2,7 +2,7 @@
     This file is part of Akonadi Contact.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -182,7 +182,7 @@ void AddressLocationWidget::fillCountryCombo()
     QStringList countries;
     const QList<QLocale> localeList = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
     countries.reserve(localeList.count());
-    foreach (const QLocale &locale, localeList) {
+    for (const QLocale &locale : localeList) {
         const QString localeStr = QLocale::countryToString(locale.country());
         if (countries.contains(localeStr)) {
             continue;
