@@ -1,7 +1,7 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (C) 2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -19,7 +19,6 @@
     02110-1301, USA.
 */
 
-
 #ifndef AKONADICONTACTSELECTTYPECOMBOBOXTEST_H
 #define AKONADICONTACTSELECTTYPECOMBOBOXTEST_H
 
@@ -29,7 +28,7 @@ class AkonadiContactSelectTypeComboboxTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit AkonadiContactSelectTypeComboboxTest(QObject *parent = Q_NULLPTR);
+    explicit AkonadiContactSelectTypeComboboxTest(QObject *parent = nullptr);
     ~AkonadiContactSelectTypeComboboxTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
