@@ -34,7 +34,7 @@ class NameEditDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit NameEditDialog(QWidget *parent = Q_NULLPTR);
+    explicit NameEditDialog(QWidget *parent = nullptr);
 
     void setFamilyName(const QString &name);
     QString familyName() const;
